@@ -1,24 +1,22 @@
-"""
-Character module (imdb package).
+# Copyright 2007-2018 Davide Alberani <da@erlug.linux.it>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+"""
 This module provides the Character class, used to store information about
 a given character.
-
-Copyright 2007-2017 Davide Alberani <da@erlug.linux.it>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
 from copy import deepcopy
@@ -30,8 +28,10 @@ from imdb.utils import _Container, analyze_name, build_name, cmpPeople, flatten
 class Character(_Container):
     """A Character.
 
-    Every information about a character can be accessed as:
+    Every information about a character can be accessed as::
+
         characterObject['information']
+
     to get a list of the kind of information stored in a
     Character object, use the keys() method; some useful aliases
     are defined (as "also known as" for the "akas" key);
@@ -109,8 +109,6 @@ class Character(_Container):
         if 'name' in self.data:
             if key == 'long imdb name':
                 return build_name(self.data)
-        if key == 'full-size headshot' and 'headshot' in self.data:
-            return self._re_fullsizeURL.sub('', self.data.get('headshot', ''))
         return None
 
     def getID(self):
