@@ -1,24 +1,22 @@
-"""
-Movie module (imdb package).
+# Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+"""
 This module provides the Movie class, used to store information about
 a given movie.
-
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
 from copy import deepcopy
@@ -31,8 +29,10 @@ from imdb.utils import analyze_title, build_title, canonicalTitle, cmpMovies, fl
 class Movie(_Container):
     """A Movie.
 
-    Every information about a movie can be accessed as:
+    Every information about a movie can be accessed as::
+
         movieObject['information']
+
     to get a list of the kind of information stored in a
     Movie object, use the keys() method; some useful aliases
     are defined (as "casting" for the "casting director" key); see
@@ -137,6 +137,8 @@ class Movie(_Container):
         'video review', 'faqs'
     )
 
+    _image_key = 'cover url'
+
     cmpFunct = cmpMovies
 
     def _init(self, **kwds):
@@ -253,8 +255,8 @@ class Movie(_Container):
                 return build_title(self.data, canonical=True)
             elif key == 'smart long imdb canonical title':
                 return build_title(self.data, canonical=True, lang=self.guessLanguage())
-        if key == 'full-size cover url' and 'cover url' in self.data:
-            return self._re_fullsizeURL.sub('', self.data.get('cover url', ''))
+        if key == 'full-size cover url':
+            return self.get_fullsizeURL()
         return None
 
     def getID(self):
