@@ -1,24 +1,22 @@
-"""
-Person module (imdb package).
+# Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+"""
 This module provides the Person class, used to store information about
 a given person.
-
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
 from copy import deepcopy
@@ -29,8 +27,10 @@ from imdb.utils import _Container, analyze_name, build_name, cmpPeople, flatten,
 class Person(_Container):
     """A Person.
 
-    Every information about a person can be accessed as:
+    Every information about a person can be accessed as::
+
         personObject['information']
+
     to get a list of the kind of information stored in a
     Person object, use the keys() method; some useful aliases
     are defined (as "biography" for the "mini biography" key);
@@ -92,6 +92,8 @@ class Person(_Container):
         "biography from leonard maltin's movie encyclopedia"
     )
 
+    _image_key = 'headshot'
+
     cmpFunct = cmpPeople
 
     def _init(self, **kwds):
@@ -162,8 +164,8 @@ class Person(_Container):
                 return build_name(self.data, canonical=False)
             elif key == 'long imdb canonical name':
                 return build_name(self.data)
-        if key == 'full-size headshot' and 'headshot' in self.data:
-            return self._re_fullsizeURL.sub('', self.data.get('headshot', ''))
+        if key == 'full-size headshot':
+            return self.get_fullsizeURL()
         return None
 
     def getID(self):
