@@ -1,34 +1,34 @@
+# Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
+#           2008-2018 H. Turgut Uyar <uyar@tekir.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """
-parser.http.searchMovieParser module (imdb package).
+This module provides the classes (and the instances) that are used to parse
+the results of a search for a given title.
 
-This module provides the HTMLSearchMovieParser class (and the
-search_movie_parser instance), used to parse the results of a search
-for a given title.
-E.g., for when searching for the title "the passion", the parsed
-page would be:
-    http://www.imdb.com/find?q=the+passion&tt=on&mx=20
+For example, when searching for the title "the passion", the parsed page
+would be:
 
-Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
-               2008 H. Turgut Uyar <uyar@tekir.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+http://www.imdb.com/find?q=the+passion&tt=on&mx=20
 """
 
-from imdb.utils import analyze_title, build_title
+from imdb.utils import analyze_title
 
-from .utils import Attribute, DOMParserBase, Extractor, analyze_imdbid
+from .piculet import Path, Rule, Rules
+from .utils import DOMParserBase, analyze_imdbid
 
 
 def custom_analyze_title(title):
@@ -46,34 +46,36 @@ class DOMHTMLSearchMovieParser(DOMParserBase):
     """Parse the html page that the IMDb web server shows when the
     "new search system" is used, for movies."""
 
-    _titleBuilder = lambda self, x: build_title(x)
     _linkPrefix = '/title/tt'
 
-    _attrs = [
-        Attribute(
+    rules = [
+        Rule(
             key='data',
-            multi=True,
-            path={
-                'link': "./a[1]/@href",
-                'info': ".//text()",
-                'akas': "./i//text()"
-            },
-            postprocess=lambda x: (
-                analyze_imdbid(x.get('link') or ''),
-                custom_analyze_title(x.get('info') or ''),
-                x.get('akas')
+            extractor=Rules(
+                foreach='//td[@class="result_text"]',
+                rules=[
+                    Rule(
+                        key='link',
+                        extractor=Path('./a[1]/@href')
+                    ),
+                    Rule(
+                        key='info',
+                        extractor=Path('.//text()')
+                    ),
+                    Rule(
+                        key='akas',
+                        extractor=Path('./i//text()')
+                    )
+                ],
+                transform=lambda x: (
+                    analyze_imdbid(x.get('link') or ''),
+                    custom_analyze_title(x.get('info') or ''),
+                    x.get('akas')
+                )
             )
         )
     ]
 
-    extractors = [
-        Extractor(
-            label='search',
-            path="//td[@class='result_text']",
-            attrs=_attrs
-        )
-    ]
-
     def _init(self):
         self.url = ''
 
