@@ -1,25 +1,23 @@
+# Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
+#           2008-2018 H. Turgut Uyar <uyar@tekir.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """
-parser.http.utils module (imdb package).
-
-This module provides miscellaneous utilities used by
-the imdb.parser.http classes.
-
-Copyright 2004-2017 Davide Alberani <da@erlug.linux.it>
-               2008 H. Turgut Uyar <uyar@tekir.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+This module provides miscellaneous utilities used by the components
+in the :mod:`imdb.parser.http` package.
 """
 
 import collections
@@ -27,13 +25,14 @@ import logging
 import re
 from html.entities import entitydefs
 
-import lxml.etree
-import lxml.html
-
 from imdb.Movie import Movie
 from imdb.Person import Person
 from imdb.utils import _Container, flatten
 
+from .piculet import ElementTree, Rules, build_tree
+from .piculet import xpath as piculet_xpath
+from .piculet import Rule, Path
+
 
 # Year, imdbIndex and kind.
 re_yearKind_index = re.compile(
@@ -89,7 +88,6 @@ entitydefsget = entitydefs.get
 entitydefs['nbsp'] = ' '
 
 sgmlentity = {'lt': '<', 'gt': '>', 'amp': '&', 'quot': '"', 'apos': '\'', 'ndash': '-'}
-sgmlentityget = sgmlentity.get
 _sgmlentkeys = list(sgmlentity.keys())
 
 entcharrefs = {}
@@ -106,15 +104,6 @@ for _k, _v in list(entitydefs.items()):
         entcharrefs[dec_code] = _v
     entcharrefs[_k] = _v
 del _sgmlentkeys, _k, _v
-entcharrefs['#160'] = ' '
-entcharrefs['#xA0'] = ' '
-entcharrefs['#xa0'] = ' '
-entcharrefs['#XA0'] = ' '
-entcharrefs['#x22'] = '"'
-entcharrefs['#X22'] = '"'
-entcharrefs['#38'] = '&amp;'
-entcharrefs['#x26'] = '&amp;'
-entcharrefs['#x26'] = '&amp;'
 
 re_entcharrefs = re.compile('&(%s|\#160|\#\d{1,5}|\#x[0-9a-f]{1,4});' %
                             '|'.join(map(re.escape, entcharrefs)), re.I)
@@ -122,50 +111,6 @@ re_entcharrefssub = re_entcharrefs.sub
 
 sgmlentity.update(dict([('#34', '"'), ('#38', '&'),
                         ('#60', '<'), ('#62', '>'), ('#39', "'")]))
-re_sgmlref = re.compile('&(%s);' % '|'.join(map(re.escape, sgmlentity)))
-re_sgmlrefsub = re_sgmlref.sub
-
-# Matches XML-only single tags, like <br/> ; they are invalid in HTML,
-# but widely used by IMDb web site. :-/
-re_xmltags = re.compile('<([a-zA-Z]+)/>')
-
-
-def _replXMLRef(match):
-    """Replace the matched XML/HTML entities and references;
-    replace everything except sgml entities like &lt;, &gt;, ..."""
-    ref = match.group(1)
-    value = entcharrefsget(ref)
-    if value is None:
-        if ref[0] == '#':
-            ref_code = ref[1:]
-            if ref_code in ('34', '38', '60', '62', '39'):
-                return match.group(0)
-            elif ref_code[0].lower() == 'x':
-                return chr(int(ref[2:], 16))
-            else:
-                return chr(int(ref[1:]))
-        else:
-            return ref
-    return value
-
-
-def subXMLRefs(s):
-    """Return the given html string with entity and char references
-    replaced."""
-    return re_entcharrefssub(_replXMLRef, s)
-
-
-# XXX: no more used here; move it to mobile (they are imported by helpers, too)?
-def _replSGMLRefs(match):
-    """Replace the matched SGML entity."""
-    ref = match.group(1)
-    return sgmlentityget(ref, ref)
-
-
-def subSGMLRefs(s):
-    """Return the given html string with sgml entity and char references
-    replaced."""
-    return re_sgmlrefsub(_replSGMLRefs, s)
 
 
 _b_p_logger = logging.getLogger('imdbpy.parser.http.build_person')
@@ -453,7 +398,7 @@ class DOMParserBase(object):
     _containsObjects = False
 
     preprocessors = []
-    extractors = []
+    rules = []
 
     _logger = logging.getLogger('imdbpy.parser.http.domparser')
 
@@ -489,10 +434,8 @@ class DOMParserBase(object):
             self.getRefs = getRefs
         else:
             self.getRefs = self._defGetRefs
-        # Useful only for the testsuite.
-        if not isinstance(html_string, str):
-            html_string = str(html_string, 'utf8', 'replace')
-        html_string = subXMLRefs(html_string)
+        # TODO: get rid of the special entity handling
+        html_string = html_string.replace('&nbsp;', ' ')
         # Temporary fix: self.parse_dom must work even for empty strings.
         html_string = self.preprocess_string(html_string)
         html_string = html_string.strip()
@@ -525,26 +468,20 @@ class DOMParserBase(object):
     def get_dom(self, html_string):
         """Return a dom object, from the given string."""
         try:
-            dom = lxml.html.fromstring(html_string)
+            dom = build_tree(html_string, force_html=True)
             if dom is None:
-                dom = lxml.html.fromstring('')
+                dom = build_tree('')
                 self._logger.error('%s: using a fake empty DOM', self._cname)
             return dom
         except Exception:
             self._logger.error('%s: caught exception parsing DOM',
                                self._cname, exc_info=True)
-            return lxml.html.fromstring('')
+            return build_tree('')
 
     def xpath(self, element, path):
         """Return elements matching the given XPath."""
         try:
-            xpath_result = element.xpath(path)
-            result = []
-            for item in xpath_result:
-                if isinstance(item, str):
-                    item = str(item)
-                result.append(item)
-            return result
+            return piculet_xpath(element, path)
         except Exception:
             self._logger.error('%s: caught exception extracting XPath "%s"',
                                self._cname, path, exc_info=True)
@@ -556,7 +493,7 @@ class DOMParserBase(object):
             return str(element)
         else:
             try:
-                return lxml.etree.tostring(element, encoding='utf8')
+                return ElementTree.tostring(element, encoding='utf8')
             except Exception:
                 self._logger.error('%s: unable to convert to string',
                                    self._cname, exc_info=True)
@@ -564,15 +501,12 @@ class DOMParserBase(object):
 
     def clone(self, element):
         """Clone an element."""
-        return lxml.html.fromstring(self.tostring(element))
+        return build_tree(self.tostring(element))
 
     def preprocess_string(self, html_string):
         """Here we can modify the text, before it's parsed."""
         if not html_string:
             return html_string
-        # Remove silly &nbsp;&raquo; and &ndash; chars.
-        html_string = html_string.replace(' \xbb', '')
-        html_string = html_string.replace('&ndash;', '-')
         try:
             preprocessors = self.preprocessors
         except AttributeError:
@@ -603,93 +537,12 @@ class DOMParserBase(object):
         self._titlesRefs = refs['titles refs']
 
     def preprocess_dom(self, dom):
-        """Last chance to modify the dom, before the rules in self.extractors
-        are applied by the parse_dom method."""
+        """Last chance to modify the dom, before the rules are applied."""
         return dom
 
     def parse_dom(self, dom):
-        """Parse the given dom according to the rules specified
-        in self.extractors."""
-        result = {}
-        for extractor in self.extractors:
-            # print extractor.label
-            if extractor.group is None:
-                elements = [(extractor.label, element)
-                            for element in self.xpath(dom, extractor.path)]
-            else:
-                groups = self.xpath(dom, extractor.group)
-                elements = []
-                for group in groups:
-                    group_key = self.xpath(group, extractor.group_key)
-                    if not group_key:
-                        continue
-                    group_key = group_key[0]
-                    group_key = self.tostring(group_key)
-                    normalizer = extractor.group_key_normalize
-                    if normalizer is not None:
-                        if isinstance(normalizer, collections.Callable):
-                            try:
-                                group_key = normalizer(group_key)
-                            except Exception:
-                                _m = '%s: unable to apply group_key normalizer'
-                                self._logger.error(_m, self._cname, exc_info=True)
-                    group_elements = self.xpath(group, extractor.path)
-                    elements.extend([(group_key, element) for element in group_elements])
-            for group_key, element in elements:
-                for attr in extractor.attrs:
-                    if isinstance(attr.path, dict):
-                        data = {}
-                        for field in list(attr.path.keys()):
-                            path = attr.path[field]
-                            value = self.xpath(element, path)
-                            if not value:
-                                data[field] = None
-                            else:
-                                # XXX: use u'' , to join?
-                                data[field] = ''.join(value)
-
-                        # If the value is to be ignored, set data to empty dict.
-                        # It will be skipped later.
-                        for key, value in attr.ignore.items():
-                            if data[key] == value:
-                                data = {}
-                    else:
-                        data = self.xpath(element, attr.path)
-                        if not data:
-                            data = None
-                        else:
-                            data = attr.joiner.join(data)
-                    if not data:
-                        continue
-                    attr_postprocess = attr.postprocess
-                    if isinstance(attr_postprocess, collections.Callable):
-                        try:
-                            data = attr_postprocess(data)
-                        except Exception:
-                            _m = '%s: unable to apply attr postprocess'
-                            self._logger.error(_m, self._cname, exc_info=True)
-                    key = attr.key
-                    if key is None:
-                        key = group_key
-                    elif key.startswith('.'):
-                        # assuming this is an xpath
-                        try:
-                            key = self.xpath(element, key)[0]
-                        except IndexError:
-                            self._logger.error('%s: XPath returned no items',
-                                               self._cname, exc_info=True)
-                    elif key.startswith('self.'):
-                        key = getattr(self, key[5:])
-                    if attr.multi:
-                        if key not in result:
-                            result[key] = []
-                        result[key].append(data)
-                    else:
-                        if isinstance(data, dict):
-                            result.update(data)
-                        else:
-                            result[key] = data
-        return result
+        """Parse the given dom according to the rules specified in self.rules."""
+        return Rules(self.rules).extract(dom)
 
     def postprocess_data(self, data):
         """Here we can modify the data."""
@@ -726,70 +579,6 @@ class DOMParserBase(object):
                 }
 
 
-class Extractor(object):
-    """Instruct the DOM parser about how to parse a document."""
-    def __init__(self, label, path, attrs, group=None, group_key=None,
-                 group_key_normalize=None):
-        """Initialize an Extractor object, used to instruct the DOM parser
-        about how to parse a document."""
-        # rarely (never?) used, mostly for debugging purposes.
-        self.label = label
-        self.group = group
-        if group_key is None:
-            self.group_key = ".//text()"
-        else:
-            self.group_key = group_key
-        self.group_key_normalize = group_key_normalize
-        self.path = path
-        # A list of attributes to fetch.
-        if isinstance(attrs, Attribute):
-            attrs = [attrs]
-        self.attrs = attrs
-
-    def __repr__(self):
-        """String representation of an Extractor object."""
-        t = '<Extractor id:%s (label=%s, path=%s, attrs=%s, group=%s, group_key=%s' + \
-            ', group_key_normalize=%s)>'
-        r = t % (id(self), self.label, self.path, repr(self.attrs), self.group,
-                 self.group_key, self.group_key_normalize)
-        return r
-
-
-class Attribute(object):
-    """The attribute to consider, for a given node."""
-    def __init__(self, key, multi=False, path=None, joiner=None,
-                 postprocess=None, ignore=None):
-        """Initialize an Attribute object, used to specify the
-        attribute to consider, for a given node."""
-        # The key under which information will be saved; can be a string or an
-        # XPath. If None, the label of the containing extractor will be used.
-        self.key = key
-        self.multi = multi
-        self.path = path
-        if joiner is None:
-            joiner = ''
-        self.joiner = joiner
-        # Post-process this set of information.
-        self.postprocess = postprocess
-
-        if ignore is not None:
-            # If there is no explicit mapping for values to ignore for particular fields,
-            # use the value for all fields.
-            if not isinstance(ignore, dict):
-                ignore = {k: ignore for k in self.path}
-        else:
-            ignore = {}
-        self.ignore = ignore
-
-    def __repr__(self):
-        """String representation of an Attribute object."""
-        r = '<Attribute id:%s (key=%s, multi=%s, path=%s, joiner=%s, postprocess=%s)>' % (
-            id(self), self.key, self.multi, repr(self.path), self.joiner,
-            repr(self.postprocess)
-        )
-        return r
-
-
 def _parse_ref(text, link, info):
     """Manage links to references."""
     if link.find('/title/tt') != -1:
@@ -801,34 +590,43 @@ def _parse_ref(text, link, info):
 
 class GatherRefs(DOMParserBase):
     """Parser used to gather references to movies, persons."""
-    _attrs = [
-        Attribute(
-            key=None,
-            multi=True,
-            path={
-                'text': './text()',
-                'link': './@href',
-                'info': './following::text()[1]'
-            },
-            postprocess=lambda x: _parse_ref(
-                x.get('text') or '',
-                x.get('link') or '',
-                (x.get('info') or '').strip()
-            )
+    _common_rules = [
+        Rule(
+            key='text',
+            extractor=Path('./text()')
+        ),
+        Rule(
+            key='link',
+            extractor=Path('./@href')
+        ),
+        Rule(
+            key='info',
+            extractor=Path('./following::text()[1]')
         )
     ]
 
-    extractors = [
-        Extractor(
-            label='names refs',
-            path="//a[starts-with(@href, '/name/nm')][string-length(@href)=16]",
-            attrs=_attrs
-        ),
+    _common_transform = lambda x: _parse_ref(
+        x.get('text') or '',
+        x.get('link') or '',
+        (x.get('info') or '').strip()
+    )
 
-        Extractor(
-            label='titles refs',
-            path="//a[starts-with(@href, '/title/tt')][string-length(@href)=17]",
-            attrs=_attrs
+    rules = [
+        Rule(
+            key='names refs',
+            extractor=Rules(
+                foreach='//a[starts-with(@href, "/name/nm")]',
+                rules=_common_rules,
+                transform=_common_transform
+            )
+        ),
+        Rule(
+            key='titles refs',
+            extractor=Rules(
+                foreach='//a[starts-with(@href, "/title/tt")]',
+                rules=_common_rules,
+                transform=_common_transform
+            )
         )
     ]
 
@@ -841,8 +639,6 @@ class GatherRefs(DOMParserBase):
                 v = v.strip()
                 if not (k and v):
                     continue
-                if not v.endswith('/'):
-                    continue
                 imdbID = analyze_imdbid(v)
                 if item == 'names refs':
                     obj = Person(personID=imdbID, name=k,
@@ -850,8 +646,6 @@ class GatherRefs(DOMParserBase):
                 elif item == 'titles refs':
                     obj = Movie(movieID=imdbID, title=k,
                                 accessSystem=self._as, modFunct=self._modFunct)
-                # XXX: companies aren't handled: are they ever found in text,
-                #      as links to their page?
                 result[item][k] = obj
         return result
 
