@@ -1,27 +1,27 @@
+# Copyright 2005-2017 Davide Alberani <da@erlug.linux.it>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """
-parser.sql package (imdb package).
-
 This package provides the IMDbSqlAccessSystem class used to access
-IMDb's data through a SQL database.  Every database supported by
-the SQLObject _AND_ SQLAlchemy Object Relational Managers is available.
-the imdb.IMDb function will return an instance of this class when
-called with the 'accessSystem' argument set to "sql", "database" or "db".
+IMDb's data through a SQL database. Every database supported by the SQLAlchemy
+object relational mapper is available.
 
-Copyright 2005-2017 Davide Alberani <da@erlug.linux.it>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+The :func:`imdb.IMDb` function will return an instance of this class
+when called with the ``accessSystem`` parameter is set to "sql",
+"database" or "db".
 """
 
 import re
