@@ -1,27 +1,24 @@
-# -*- encoding: utf-8 -*-
+# Copyright 2005-2017 Davide Alberani <da@erlug.linux.it>
+#                2006 Giuseppe "Cowo" Corbelli <cowo --> lugbs.linux.it>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 """
-parser.sql.dbschema module (imdb.parser.sql package).
-
-This module provides the schema used to describe the layout of the
-database used by the imdb.parser.sql package; functions to create/drop
+This module provides the schema used to describe the layout of the database
+used by the :mod:`imdb.parser.sql` package; functions to create/drop
 tables and indexes are also provided.
-
-Copyright 2005-2017 Davide Alberani <da@erlug.linux.it>
-               2006 Giuseppe "Cowo" Corbelli <cowo --> lugbs.linux.it>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
 import logging
