@@ -1,27 +1,24 @@
-"""
-utils module (imdb package).
+# Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
+#                2009 H. Turgut Uyar <uyar@tekir.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+"""
 This module provides basic utilities for the imdb package.
-
-Copyright 2004-2018 Davide Alberani <da@erlug.linux.it>
-               2009 H. Turgut Uyar <uyar@tekir.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
-
 import logging
 import re
 import string
@@ -1129,8 +1126,8 @@ class _Container(object):
     # Function used to compare two instances of this class.
     cmpFunct = None
 
-    # Regular expression used to build the 'full-size (headshot|cover url)'.
-    _re_fullsizeURL = re.compile(r'\._V1\._SX(\d+)_SY(\d+)_')
+    # key that contains the cover/headshot
+    _image_key = None
 
     def __init__(self, myID=None, data=None, notes='',
                  currentRole='', roleID=None, roleIsPerson=False,
@@ -1255,6 +1252,14 @@ class _Container(object):
     def _init(self, **kwds):
         pass
 
+    def get_fullsizeURL(self):
+        """Return the full-size URL for this object."""
+        if not (self._image_key and self._image_key in self.data):
+            return None
+        url = self.data[self._image_key] or ''
+        ext_idx = url.rfind('.')
+        return url[:url.rindex('@')+1] + url[ext_idx:]
+
     def reset(self):
         """Reset the object."""
         self.data = {}
